@@ -1,6 +1,6 @@
 package PITA::POE::SupportServer;
 
-use 5.005;
+use 5.006;
 use strict;
 use Params::Util qw( _ARRAY _HASH0 );
 
@@ -13,7 +13,7 @@ use base 'Process';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.40';
+	$VERSION = '0.41';
 }
 
 sub new {
@@ -357,7 +357,7 @@ __END__
 
 =head1 NAME
 
-PITA::POE::SupportServer
+PITA::POE::SupportServer - Support server for PITA virtual machines
 
 =head1 SYNOPSIS
 
@@ -390,11 +390,16 @@ PITA::POE::SupportServer
   my $result_file = $server->http_result('/result.xml')
           or die "Guest Image execution failed";
 
-=head1 ABSTRACT
-
 =head1 DESCRIPTION
 
-=head1 METHODS
+TO BE COMPLETED
+
+=head1 SUPPORT 
+Bugs should be reported via the CPAN bug tracker at
+
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PITA-POE-SupportServer>
+
+For other issues, contact the author.
 
 =head1 AUTHORS
 
@@ -410,7 +415,7 @@ L<PITA>, L<POE>, L<Process>, L<http://ali.as/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 David Davis.
+Copyright 2006 - 2008 David Davis.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
